==> diveRsity_1.7.6.tar.gz: diveRsity/man/divMigrate.Rd <==
\name{divMigrate}
\alias{divMigrate}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
An experimental function for the detection of directional differentiation from microsatellite data.
}

\description{
\code{divMigrate} uses the method described in Sundqvist \emph{et al.,} 2013 to plot the relative migration levels between population samples, from microsatellite allele frequency data. The method is still in the experimental stages, and it is not clear how well it performs under most evolutionary scenarios. Caution should be exercised.
}

\details{
The function will except both Arlequin (.arp) genotype and genepop (.gen/.txt) files, containing co-dominant diploid data. Using the method outlined in Sundqvist \emph{et al.,} 2013, the relative migration levels between all pairs of populations is determined. A weighted network plot is returned, as well as four matrices containing the objects described below.
}

\usage{
divMigrate(infile = NULL, stat = "d_jost")
}
\arguments{

\item{infile}{Should either be a character string of the input file name or pathway to the input file. This file should be in either the Arlequin genotype file format (.arp), or in the genepop file format.}

\item{stat}{A character vector of the value \code{stat = 'gst'}, \code{stat = 'd_jost'} (default), or \code{stat = c('gst', 'd_jost')}. This argument specifies which statistic should be used to calculate relative migration between samples.}

}

\value{

\item{D_mig}{A pairwise matrix containing the normalized relative migration values for all population pairs, as determined by $D_{Jost}$ values}

\item{Gst_mig}{A pairwise matrix containing the normalized relative migration values for all population pairs, as determined by $G_{ST}$ values}

}

\references{
Lisa Sundqvist, M.Z. & Kleinhans, D., 2013. Directional genetic differentiation and asymmetric migration. arXiv pre-print: arXiv:1304.0118v2

Rousset, F., ``genepop'007: a complete re-implementation of the genepop
software for Windows and Linux.,'' Molecular ecology resources, vol. 8,
no. 1, pp. 103-6, (2008).
}

\author{
Kevin Keenan <kkeenan02@qub.ac.uk>
}

==> diveRsity_1.9.5.tar.gz: diveRsity/man/divMigrate.Rd <==
\name{divMigrate}
\alias{divMigrate}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
An experimental function for the detection of directional differentiation from microsatellite data.
}

\description{
\code{divMigrate} uses the method described in Sundqvist \emph{et al.,} 2013 to plot the relative migration levels between population samples, from microsatellite allele frequency data. The method is still in the experimental stages, and it is not clear how well it performs under most evolutionary scenarios. Caution should be exercised.
}

\details{
The function will except both Arlequin (.arp) genotype and genepop (.gen/.txt) files, containing co-dominant diploid data. Using the method outlined in Sundqvist \emph{et al.,} 2013, the relative migration levels between all pairs of populations is determined. A weighted network plot is returned, as well as four matrices containing the objects described below.
}

\usage{
divMigrate(infile = NULL, nbs = 0, filter_threshold = 0, plot = FALSE, 
           plot_col = "darkblue", para = FALSE)
}
\arguments{

\item{infile}{Input genepop file name or path.}

\item{nbs}{The number of bootstrap iteration to carry out for calculating mean relative migration and 95\% confidence intervals.}

\item{filter_threshold}{The minimum relative migration value for which edges in the networks should be displayed.}

\item{plot}{A logical argument, specifying whether migration results should be plotted in a network.}

\item{plot_col}{Defines the colour of edges in networks. Default is set to "\code{darkblue}".}

\item{para}{A logical argument, specifying if multiple CPUs should be used when available.}

}

\value{

\item{relMig}{relative migration matrix}

\item{bsRelMig}{If \code{nbs > 0} a relative migration matrix is calculated as the mean of bootstrap matrices.}

}

\references{
Lisa Sundqvist, M.Z. & Kleinhans, D., 2013. Directional genetic differentiation and asymmetric migration. arXiv pre-print: arXiv:1304.0118v2

Rousset, F., ``genepop'007: a complete re-implementation of the genepop
software for Windows and Linux.,'' Molecular ecology resources, vol. 8,
no. 1, pp. 103-6, (2008).
}

\author{
Kevin Keenan <kkeenan02@qub.ac.uk>
}
